import quixote
from quixote import get_context
import quixote.build.apt as apt
import quixote.fetch.copy as fetch
from quixote.inspection.build import gcc
from quixote.inspection.diff import diff_exec
from quixote.inspection import InternalError


@quixote.builder
def setup():
    apt.update()
    apt.install("gcc")


@quixote.fetcher
def fetch_by_copying():
    fetch.copy("/tmp/deliveries")


@quixote.inspector(critical=True)
def compile():
    resources_path = get_context()["resources_path"]
    delivery_path = get_context()["delivery_path"]
    gcc(f"{resources_path}/main.c", f"{delivery_path}/my_is_even.c", output_file="student") \
        .check("unable to compile your exercise")
    gcc(f"{resources_path}/main.c", f"{resources_path}/cor_my_is_even.c", output_file="correction") \
        .check("unable to compile the correction", error_kind=InternalError)


@quixote.inspector
def execute_and_diff():
    diff_exec("./correction", "./student").check("your output differs from the correction's output")


blueprint = quixote.Blueprint(
    name="c_pool_day_01_my_is_even",
    author="Clément Doumergue",
)
